// src/components/ItemDetails.js
import React, { useState, useEffect, useRef } from 'react';
import { TextField, Button, Container, Avatar } from '@mui/material';
import axios from 'axios';
import { PRIMARY_COLOR, SECONDARY_COLOR } from '../App';
//import { useNavigate } from 'react-router-dom'; // Import useNavigate

export default function ItemDetails({ item, token, onSave, onClose, boxId }) {
  const [name, setName] = useState(item.name);
  const [description, setDescription] = useState(item.description);
  const [imagePath, setImagePath] = useState(item.image_path || '');
  const [imageSrc, setImageSrc] = useState('/images/default.jpg'); // Initial default image
  const fileInputRef = useRef(null); // Add this line to define fileInputRef
  const [imageOverlayVisible, setImageOverlayVisible] = useState(false);
  // const navigate = useNavigate(); // Initialize useNavigate

  useEffect(() => {
    // Function to fetch image similar to getImageSrc in Items.js
    const getImageSrc = (itemId) => {
      return axios.get(`${process.env.REACT_APP_API_URL}/items/${itemId}/image`, {
        headers: { Authorization: `Bearer ${token}` },
        responseType: 'blob'
      })
      .then(response => {
        if (response.status === 200) {
          return new Promise((resolve, reject) => {
            const reader = new FileReader();
            reader.onload = () => resolve(reader.result);
            reader.onerror = reject;
            reader.readAsDataURL(response.data);
          });
        } else {
          throw new Error('Image fetch failed');
        }
      })
      .catch(() => {
        // Return the data URL of the default image if image fetch fails
        return new Promise((resolve, reject) => {
          const img = new Image();
          img.src = '/default.jpg'; 
          img.onload = () => {
            const canvas = document.createElement('canvas');
            canvas.width = img.width;
            canvas.height = img.height;
            const ctx = canvas.getContext('2d');
            ctx.drawImage(img, 0, 0);
            const dataURL = canvas.toDataURL();
            resolve(dataURL);
          };
          img.onerror = reject;
        });
      });
    };

    // Fetch the image when the component mounts or the item changes
    getImageSrc(item.ID).then(dataUrl => setImageSrc(dataUrl));
  }, [item.ID, token]);

  // const handleCloseItemDetails = () => {
  //   onClose(); // Call the onClose prop to close the modal
  //   navigate(`/boxes/${boxId}/items`); // Navigate back to the items list
  // };

  const handleImageUpload = async () => {
    const formData = new FormData();
    formData.append('image', fileInputRef.current.files[0]);

    try {
      const response = await axios.post(`${process.env.REACT_APP_API_URL}/items/${item.ID}/upload`, formData, {
        headers: {
          Authorization: `Bearer ${token}`,
          'Content-Type': 'multipart/form-data'
        }
      });
      // Handle successful upload (e.g., show a success message)
      console.log('Image uploaded successfully!', response.data.imagePath);
      return response.data.imagePath; // Indicate successful upload
    } catch (error) {
      // Handle upload error (e.g., show an error message)
      console.error('Image upload failed:', error);
    }
  };

  const handleSave = async () => {
    let imagePath;
    // 1. Handle image upload first if a new image is selected
    if (fileInputRef.current.files[0]) {
      imagePath = await handleImageUpload();
    }

    // 2. Update item details (name, description, etc.)
    try {
      await axios.put(`${process.env.REACT_APP_API_URL}/items/${item.ID}`,
        { name, description, image_path: imagePath }, // Use teh uploaded image path
        {
          headers: { Authorization: `Bearer ${token}` }
        }
      );
      onSave(); // Notify parent to refresh items
    } catch (error) {
      // Handle update error
      console.error('Item update failed:', error);
    }
  };

  const handleImageError = (e) => {
    e.target.src = '/images/default.jpg'; // Fallback to default image on error
  };

  const handleAvatarClick = () => {
    setImageOverlayVisible(true);
  };
  
  const handleCloseOverlay = () => {
    setImageOverlayVisible(false);
  };

  return (
    <Container>
      <h3>Edit Item: {item.name}</h3>

      {/* Display the item image as an avatar */}
      <Avatar
        src={imageSrc}
        alt={name}
        onError={handleImageError}
        sx={{ width: 100, height: 100, marginBottom: '16px' }} // Style the Avatar
        onClick={handleAvatarClick}
      />
      {imageOverlayVisible && (
        <div className="image-overlay">
          <img src={imageSrc} alt={name} />
          <button className="close-button" onClick={handleCloseOverlay}>
            Close
          </button>
        </div>
      )}
      <TextField
        label="Item Name"
        variant="outlined"
        fullWidth
        margin="normal"
        value={name}
        onChange={(e) => setName(e.target.value)}
      />
      <TextField
        label="Item Description"
        variant="outlined"
        fullWidth
        margin="normal"
        value={description}
        onChange={(e) => setDescription(e.target.value)}
      />
      <TextField 
        label="Item Image Path" 
        variant="outlined" 
        fullWidth 
        margin="normal"
        value={imagePath}
        onChange={(e) => setImagePath(e.target.value)} 
      />
      <input 
        type="file" 
        accept="image/*" 
        ref={fileInputRef} 
        style={{ display: 'none' }} 
        id="editItemImageUpload" // Unique ID
      />
      <Button sx={{ backgroundColor: PRIMARY_COLOR, borderBottom: '1px solid', borderColor: '#444', color: SECONDARY_COLOR }} variant="contained" component="label" htmlFor="editItemImageUpload"> 
        Upload Image
        <input 
          type="file" 
          accept="image/*" 
          id="image-upload" 
          style={{ display: 'none' }} 
          onChange={(e) => {
            // You can handle image preview here if needed
            setImagePath(e.target.files[0].name); 
          }}
        />
      </Button>

      <Button sx={{ backgroundColor: PRIMARY_COLOR, borderBottom: '1px solid', borderColor: '#444', color: SECONDARY_COLOR }} variant="contained" color="primary" onClick={handleSave}>
        Save Changes
      </Button>
      <Button sx={{ backgroundColor: PRIMARY_COLOR, borderBottom: '1px solid', borderColor: '#444', color: SECONDARY_COLOR }} variant="contained" color="primary" onClick={onClose}>Close</Button>
    </Container>
  );
}